@@ -11,15 +11,18 @@ public class Genre extends MediaLibraryItem {
         super(id, title);
     }
 
-    public Album[] getAlbums(Medialibrary ml) {
+    public Album[] getAlbums() {
+       Medialibrary ml = Medialibrary.getInstance();
        return ml != null && ml.isInitiated() ? nativeGetAlbumsFromGenre(ml, mId) : new Album[0];
     }
 
-    public Artist[] getArtists(Medialibrary ml) {
+    public Artist[] getArtists() {
+        Medialibrary ml = Medialibrary.getInstance();
         return ml != null && ml.isInitiated() ? nativeGetArtistsFromGenre(ml, mId) : new Artist[0];
     }
 
-    public MediaWrapper[] getTracks(Medialibrary ml) {
+    public MediaWrapper[] getTracks() {
+        Medialibrary ml = Medialibrary.getInstance();
         return ml != null && ml.isInitiated() ? nativeGetTracksFromGenre(ml, mId) : Medialibrary.EMPTY_COLLECTION;
     }
 
