@@ -20,6 +20,7 @@
 
 package org.videolan.vlc.gui.audio;
 
+import android.content.Context;
 import android.content.Intent;
 import android.os.Bundle;
 import android.os.Handler;
@@ -29,24 +30,24 @@ import android.support.v4.app.FragmentManager;
 import android.support.v4.view.ViewPager;
 import android.support.v7.widget.LinearLayoutManager;
 import android.support.v7.widget.RecyclerView;
-import android.text.TextUtils;
 import android.view.LayoutInflater;
 import android.view.Menu;
 import android.view.MenuItem;
 import android.view.MotionEvent;
 import android.view.View;
 import android.view.ViewGroup;
+import android.widget.Filter;
 
 import org.videolan.medialibrary.Medialibrary;
 import org.videolan.medialibrary.media.Album;
 import org.videolan.medialibrary.media.Artist;
-import org.videolan.medialibrary.media.DummyItem;
 import org.videolan.medialibrary.media.Genre;
 import org.videolan.medialibrary.media.MediaLibraryItem;
 import org.videolan.medialibrary.media.MediaWrapper;
 import org.videolan.vlc.R;
 import org.videolan.vlc.VLCApplication;
 import org.videolan.vlc.gui.PlaylistActivity;
+import org.videolan.vlc.gui.SecondaryActivity;
 import org.videolan.vlc.gui.dialogs.SavePlaylistDialog;
 import org.videolan.vlc.gui.helpers.AudioUtil;
 import org.videolan.vlc.gui.helpers.UiTools;
@@ -59,8 +60,6 @@ import org.videolan.vlc.util.FileUtils;
 import org.videolan.vlc.util.Util;
 
 import java.util.ArrayList;
-import java.util.Arrays;
-import java.util.LinkedList;
 
 public class AudioAlbumsSongsFragment extends BaseAudioBrowser implements SwipeRefreshLayout.OnRefreshListener, TabLayout.OnTabSelectedListener {
 
@@ -76,6 +75,7 @@ public class AudioAlbumsSongsFragment extends BaseAudioBrowser implements SwipeR
     private AudioBrowserAdapter mSongsAdapter;
     private AudioBrowserAdapter mAlbumsAdapter;
     private FastScroller mFastScroller;
+    //private View mSearchButtonView;
 
     private final static int MODE_ALBUM = 0;
     private final static int MODE_SONG = 1;
@@ -89,6 +89,8 @@ public class AudioAlbumsSongsFragment extends BaseAudioBrowser implements SwipeR
     @Override
     public void onCreate(Bundle savedInstanceState) {
         super.onCreate(savedInstanceState);
+        if (savedInstanceState == null)
+            AudioBrowserAdapter.sMediaComparator.setSortDefault();
 
         mMediaLibrary = VLCApplication.getMLInstance();
         mItem = (MediaLibraryItem) (savedInstanceState != null ?
@@ -104,6 +106,10 @@ public class AudioAlbumsSongsFragment extends BaseAudioBrowser implements SwipeR
         return mItem.getTitle();
     }
 
+    public Filter getFilter() {
+        return getCurrentAdapter().getFilter();
+    }
+
     @Override
     public View onCreateView(LayoutInflater inflater, ViewGroup container, Bundle savedInstanceState) {
 
@@ -115,8 +121,11 @@ public class AudioAlbumsSongsFragment extends BaseAudioBrowser implements SwipeR
 
         mLists = new ContextMenuRecyclerView[]{albumsList, songsList};
         String[] titles = new String[] {getString(R.string.albums), getString(R.string.songs)};
-        mAlbumsAdapter = new AudioBrowserAdapter(getActivity(), MediaLibraryItem.TYPE_ALBUM, this, false);
-        mSongsAdapter = new AudioBrowserAdapter(getActivity(), MediaLibraryItem.TYPE_MEDIA, this, false);
+        mAlbumsAdapter = new AudioBrowserAdapter(getActivity(), MediaLibraryItem.TYPE_ALBUM, this, true);
+        mSongsAdapter = new AudioBrowserAdapter(getActivity(), MediaLibraryItem.TYPE_MEDIA, this, true);
+        mAlbumsAdapter.setParentAdapterType(mItem.getItemType());
+        mSongsAdapter.setParentAdapterType(mItem.getItemType());
+        mAdapters = new AudioBrowserAdapter[]{mAlbumsAdapter, mSongsAdapter};
 
         songsList.setAdapter(mSongsAdapter);
         albumsList.setAdapter(mAlbumsAdapter);
@@ -131,7 +140,7 @@ public class AudioAlbumsSongsFragment extends BaseAudioBrowser implements SwipeR
 
         mSwipeRefreshLayout = (SwipeRefreshLayout) v.findViewById(R.id.swipeLayout);
         mSwipeRefreshLayout.setOnRefreshListener(this);
-
+        mSearchButtonView = v.findViewById(R.id.searchButton);
         return v;
     }
 
@@ -158,6 +167,12 @@ public class AudioAlbumsSongsFragment extends BaseAudioBrowser implements SwipeR
             registerForContextMenu(rv);
     }
 
+    @Override
+    public void onAttach(Context context) {
+        super.onAttach(context);
+        mActivity = (SecondaryActivity) context;
+    }
+
     @Override
     public void onStop() {
         super.onStop();
@@ -167,6 +182,7 @@ public class AudioAlbumsSongsFragment extends BaseAudioBrowser implements SwipeR
 
     @Override
     public void onRefresh() {
+        mActivity.closeSearchView();
         updateList();
     }
 
@@ -207,7 +223,7 @@ public class AudioAlbumsSongsFragment extends BaseAudioBrowser implements SwipeR
 
             adapter.remove(mediaItem);
 
-            UiTools.snackerWithCancel(getView(), getString(R.string.file_deleted), new Runnable() {
+            UiTools.snackerWithCancel(mViewPager, getString(R.string.file_deleted), new Runnable() {
                 @Override
                 public void run() {
                     deleteMedia(mediaItem, true);
@@ -235,7 +251,7 @@ public class AudioAlbumsSongsFragment extends BaseAudioBrowser implements SwipeR
             FragmentManager fm = getActivity().getSupportFragmentManager();
             SavePlaylistDialog savePlaylistDialog = new SavePlaylistDialog();
             Bundle args = new Bundle();
-            args.putParcelableArray(SavePlaylistDialog.KEY_NEW_TRACKS, mediaItem.getTracks(mMediaLibrary));
+            args.putParcelableArray(SavePlaylistDialog.KEY_NEW_TRACKS, mediaItem.getTracks());
             savePlaylistDialog.setArguments(args);
             savePlaylistDialog.show(fm, "fragment_add_to_playlist");
             return true;
@@ -248,7 +264,7 @@ public class AudioAlbumsSongsFragment extends BaseAudioBrowser implements SwipeR
         } else {
             startPosition = 0;
             if (mediaItem instanceof Album)
-                medias = mediaItem.getTracks(mMediaLibrary);
+                medias = mediaItem.getTracks();
             else
                 medias = new MediaWrapper[] {(MediaWrapper) mediaItem};
         }
@@ -272,28 +288,23 @@ public class AudioAlbumsSongsFragment extends BaseAudioBrowser implements SwipeR
         VLCApplication.runBackground(new Runnable() {
             @Override
             public void run() {
-                final ArrayList<? extends MediaLibraryItem> albums;
+                final ArrayList<MediaLibraryItem> albums;
                 if (mItem.getItemType() == MediaLibraryItem.TYPE_ARTIST) {
-                    albums = Util.arrayToArrayList(((Artist) mItem).getAlbums(mMediaLibrary));
-                }
-                else if (mItem.getItemType() == MediaLibraryItem.TYPE_GENRE)
-                    albums = Util.arrayToArrayList(((Genre) mItem).getAlbums(mMediaLibrary));
+                    albums = Util.arrayToMediaArrayList(((Artist) mItem).getAlbums());
+                } else if (mItem.getItemType() == MediaLibraryItem.TYPE_GENRE)
+                    albums = Util.arrayToMediaArrayList(((Genre) mItem).getAlbums());
                 else
                     return;
-                final LinkedList<MediaLibraryItem> songs = new LinkedList<>();
-                for (Album album : (ArrayList<Album>) albums) {
-                    String title = album.getTitle();
-                    if (TextUtils.isEmpty(title))
-                        title = getString(R.string.unknown_album);
-                    songs.add(new DummyItem(title));
-                    songs.addAll(Arrays.asList(album.getTracks(mMediaLibrary)));
+                final ArrayList<MediaLibraryItem> songs = new ArrayList<>();
+                for (MediaLibraryItem album : albums) {
+                    songs.addAll(Util.arrayToArrayList(album.getTracks()));
                 }
                 mHandler.post(new Runnable() {
                     @Override
                     public void run() {
                         mAlbumsAdapter.update(albums);
                         mSongsAdapter.update(new ArrayList<>(songs));
-                        mFastScroller.setRecyclerView(mLists[mViewPager.getCurrentItem()]);
+                        mFastScroller.setRecyclerView(getCurrentRV());
                         mSwipeRefreshLayout.setRefreshing(false);
                     }
                 });
@@ -344,6 +355,7 @@ public class AudioAlbumsSongsFragment extends BaseAudioBrowser implements SwipeR
 
     @Override
     public void onTabSelected(TabLayout.Tab tab) {
+        getActivity().supportInvalidateOptionsMenu();
         mFastScroller.setRecyclerView(mLists[tab.getPosition()]);
     }
 
@@ -358,8 +370,8 @@ public class AudioAlbumsSongsFragment extends BaseAudioBrowser implements SwipeR
         mLists[tab.getPosition()].smoothScrollToPosition(0);
     }
 
-    protected AudioBrowserAdapter getCurrentAdapter() {
-        return (AudioBrowserAdapter) (getCurrentRV()).getAdapter();
+    public AudioBrowserAdapter getCurrentAdapter() {
+        return (AudioBrowserAdapter) getCurrentRV().getAdapter();
     }
 
     private ContextMenuRecyclerView getCurrentRV() {
@@ -369,4 +381,5 @@ public class AudioAlbumsSongsFragment extends BaseAudioBrowser implements SwipeR
     protected boolean songModeSelected() {
         return mViewPager.getCurrentItem() == MODE_SONG;
     }
+
 }
