@@ -106,7 +106,7 @@ public class AudioPlayer extends PlaybackServiceFragment implements PlaybackServ
 
     // Tips
     private static final String PREF_PLAYLIST_TIPS_SHOWN = "playlist_tips_shown";
-    private static final String PREF_AUDIOPLAYER_TIPS_SHOWN = "audioplayer_tips_shown";
+    public static final String PREF_AUDIOPLAYER_TIPS_SHOWN = "audioplayer_tips_shown";
 
     @Override
     public void onCreate(@Nullable Bundle savedInstanceState) {
@@ -161,11 +161,6 @@ public class AudioPlayer extends PlaybackServiceFragment implements PlaybackServ
         }
     }
 
-    @Override
-    public void onStart() {
-        super.onStart();
-    }
-
     @Override
     public void onSaveInstanceState(Bundle outState) {
         super.onSaveInstanceState(outState);
@@ -417,7 +412,7 @@ public class AudioPlayer extends PlaybackServiceFragment implements PlaybackServ
         if (mService.hasNext())
             mService.next();
         else
-            Snackbar.make(getView(), R.string.lastsong, Snackbar.LENGTH_SHORT).show();
+            Snackbar.make(mBinding.getRoot(), R.string.lastsong, Snackbar.LENGTH_SHORT).show();
     }
 
     public void onPreviousClick(View view) {
@@ -426,7 +421,7 @@ public class AudioPlayer extends PlaybackServiceFragment implements PlaybackServ
         if (mService.hasPrevious() || mService.isSeekable())
             mService.previous(false);
         else
-            Snackbar.make(getView(), R.string.firstsong, Snackbar.LENGTH_SHORT).show();
+            Snackbar.make(mBinding.getRoot(), R.string.firstsong, Snackbar.LENGTH_SHORT).show();
     }
 
     public void onRepeatClick(View view) {
@@ -751,12 +746,6 @@ public class AudioPlayer extends PlaybackServiceFragment implements PlaybackServ
             activity.showTipViewIfNeeded(R.id.audio_playlist_tips, PREF_PLAYLIST_TIPS_SHOWN);
     }
 
-    public void showAudioPlayerTips() {
-        AudioPlayerContainerActivity activity = (AudioPlayerContainerActivity)getActivity();
-        if (activity != null)
-            activity.showTipViewIfNeeded(R.id.audio_player_tips, PREF_AUDIOPLAYER_TIPS_SHOWN);
-    }
-
     public void onStateChanged(int newState) {
         mPlayerState = newState;
         switch (newState) {
@@ -776,15 +765,6 @@ public class AudioPlayer extends PlaybackServiceFragment implements PlaybackServ
         }
     }
 
-    /*
-     * Override this method to prefent NPE on mFragmentManager reference.
-     */
-    @Override
-    public void setUserVisibleHint(boolean isVisibleToUser) {
-        if (getFragmentManager() != null)
-            super.setUserVisibleHint(isVisibleToUser);
-    }
-
     static final int UPDATE = 0;
     private Handler mHandler = new Handler() {
         @Override
