@@ -2,7 +2,7 @@
  * *************************************************************************
  *  BaseAudioBrowser.java
  * **************************************************************************
- *  Copyright © 2016 VLC authors and VideoLAN
+ *  Copyright © 2016-2017 VLC authors and VideoLAN
  *  Author: Geoffrey Métais
  *
  *  This program is free software; you can redistribute it and/or modify
@@ -23,6 +23,7 @@
 
 package org.videolan.vlc.gui.audio;
 
+import android.content.Intent;
 import android.support.v7.view.ActionMode;
 import android.support.v7.widget.RecyclerView;
 import android.view.Menu;
@@ -31,20 +32,26 @@ import android.view.View;
 
 import org.videolan.medialibrary.media.MediaLibraryItem;
 import org.videolan.medialibrary.media.MediaWrapper;
+import org.videolan.vlc.PlaybackService;
 import org.videolan.vlc.R;
-import org.videolan.vlc.gui.browser.MediaBrowserFragment;
+import org.videolan.vlc.gui.ContentActivity;
+import org.videolan.vlc.gui.browser.SortableFragment;
 import org.videolan.vlc.gui.helpers.AudioUtil;
 import org.videolan.vlc.gui.helpers.UiTools;
+import org.videolan.vlc.interfaces.Filterable;
 import org.videolan.vlc.interfaces.IEventsHandler;
 import org.videolan.vlc.util.AndroidDevices;
+import org.videolan.vlc.util.MediaLibraryItemComparator;
 
 import java.util.ArrayList;
 import java.util.Arrays;
 import java.util.List;
 
-public abstract class BaseAudioBrowser extends MediaBrowserFragment implements IEventsHandler {
+public abstract class BaseAudioBrowser extends SortableFragment<AudioBrowserAdapter> implements IEventsHandler, Filterable {
 
-    abstract protected AudioBrowserAdapter getCurrentAdapter();
+    public View mSearchButtonView;
+    public ContentActivity mActivity;
+    protected AudioBrowserAdapter[] mAdapters;
 
     protected void inflate(Menu menu, int position) {
         if (getActivity() == null)
@@ -52,6 +59,30 @@ public abstract class BaseAudioBrowser extends MediaBrowserFragment implements I
         getActivity().getMenuInflater().inflate(R.menu.audio_list_browser, menu);
     }
 
+    @Override
+    public void onPrepareOptionsMenu(Menu menu) {
+        super.onPrepareOptionsMenu(menu);
+        AudioBrowserAdapter adapter = getCurrentAdapter();
+        menu.findItem(R.id.ml_menu_last_playlist).setVisible(true);
+        menu.findItem(R.id.ml_menu_sortby_name).setVisible(adapter.isSortAllowed(MediaLibraryItemComparator.SORT_BY_TITLE));
+        menu.findItem(R.id.ml_menu_sortby_artist_name).setVisible(adapter.isSortAllowed(MediaLibraryItemComparator.SORT_BY_ARTIST));
+        menu.findItem(R.id.ml_menu_sortby_album_name).setVisible(adapter.isSortAllowed(MediaLibraryItemComparator.SORT_BY_ALBUM));
+        menu.findItem(R.id.ml_menu_sortby_length).setVisible(adapter.isSortAllowed(MediaLibraryItemComparator.SORT_BY_LENGTH));
+        menu.findItem(R.id.ml_menu_sortby_date).setVisible(adapter.isSortAllowed(MediaLibraryItemComparator.SORT_BY_DATE));
+        menu.findItem(R.id.ml_menu_sortby_number).setVisible(adapter.isSortAllowed(MediaLibraryItemComparator.SORT_BY_NUMBER));
+    }
+
+    @Override
+    public boolean onOptionsItemSelected(MenuItem item) {
+        switch (item.getItemId()) {
+            case R.id.ml_menu_last_playlist:
+                getActivity().sendBroadcast(new Intent(PlaybackService.ACTION_REMOTE_LAST_PLAYLIST));
+                return true;
+            default:
+                return super.onOptionsItemSelected(item);
+        }
+    }
+
     @Override
     public boolean onCreateActionMode(ActionMode mode, Menu menu) {
         mode.getMenuInflater().inflate(R.menu.action_mode_audio_browser, menu);
@@ -81,7 +112,7 @@ public abstract class BaseAudioBrowser extends MediaBrowserFragment implements I
         if (!list.isEmpty()) {
             ArrayList<MediaWrapper> tracks = new ArrayList<>();
             for (MediaLibraryItem mediaItem : list)
-                tracks.addAll(Arrays.asList(mediaItem.getTracks(mMediaLibrary)));
+                tracks.addAll(Arrays.asList(mediaItem.getTracks()));
             switch (item.getItemId()) {
                 case R.id.action_mode_audio_play:
                     mService.load(tracks, 0);
@@ -156,4 +187,35 @@ public abstract class BaseAudioBrowser extends MediaBrowserFragment implements I
 
     @Override
     public void onUpdateFinished(RecyclerView.Adapter adapter) {}
+
+    public void restoreList() {
+        getCurrentAdapter().restoreList();
+    }
+
+    @Override
+    public boolean enableSearchOption() {
+        return true;
+    }
+
+    @Override
+    public void setSearchVisibility(boolean visible) {
+        UiTools.setViewVisibility(mSearchButtonView, visible ? View.VISIBLE : View.GONE);
+    }
+
+    @Override
+    public void sortBy(int newSortby) {
+        AudioBrowserAdapter adapter = mAdapters[0];
+        int sortDirection = adapter.getSortDirection();
+        int oldSortby = adapter.getSortBy();
+        int delfaultSortby = getCurrentAdapter().getDefaultSort();
+        int defaultDirection = getCurrentAdapter().getDefaultDirection();
+        if (newSortby == oldSortby)
+            sortDirection*=-1;
+        else if (newSortby == delfaultSortby)
+            sortDirection = defaultDirection*-1;
+        else
+            sortDirection = 1;
+        for (AudioBrowserAdapter audioBrowserAdapter : mAdapters)
+            audioBrowserAdapter.sortBy(newSortby, sortDirection);
+    }
 }
