@@ -49,18 +49,16 @@ import android.widget.TextView;
 import android.widget.Toast;
 
 import org.videolan.libvlc.MediaPlayer;
-import org.videolan.libvlc.util.AndroidUtil;
 import org.videolan.vlc.PlaybackService;
 import org.videolan.vlc.R;
 import org.videolan.vlc.VLCApplication;
 import org.videolan.vlc.gui.PlaybackServiceFragment;
-import org.videolan.vlc.gui.SecondaryActivity;
+import org.videolan.vlc.gui.audio.EqualizerFragment;
 import org.videolan.vlc.gui.helpers.UiTools;
 import org.videolan.vlc.gui.video.VideoPlayerActivity;
 import org.videolan.vlc.gui.view.AutoFitRecyclerView;
 import org.videolan.vlc.interfaces.IPlaybackSettingsController;
 import org.videolan.vlc.util.AndroidDevices;
-import org.videolan.vlc.util.Permissions;
 import org.videolan.vlc.util.Strings;
 
 import java.util.ArrayList;
@@ -227,6 +225,10 @@ public class AdvOptionsDialog extends DialogFragment implements View.OnClickList
                 newFragment = SelectChapterDialog.newInstance(mTheme);
                 tag = "select_chapter";
                 break;
+            case ID_EQUALIZER:
+                newFragment = new EqualizerFragment();
+                tag = "equalizer";
+                break;
             case ID_SAVE_PLAYLIST:
                 UiTools.addToPlaylist(getActivity(), mService.getMedias());
                 dismiss();
@@ -471,20 +473,10 @@ public class AdvOptionsDialog extends DialogFragment implements View.OnClickList
                 ((VideoPlayerActivity)getActivity()).switchToAudioMode(true);
                 break;
             case ID_POPUP_VIDEO:
-                if (AndroidUtil.isOOrLater || VLCApplication.showTvUi()) {
-                    getActivity().enterPictureInPictureMode();
-                } else {
-                    if (Permissions.canDrawOverlays(mActivity))
-                        ((VideoPlayerActivity)getActivity()).switchToPopupMode();
-                    else
-                        Permissions.checkDrawOverlaysPermission(mActivity);
-                }
+                ((VideoPlayerActivity)getActivity()).switchToPopup();
                 break;
             case ID_EQUALIZER:
-                Intent i = new Intent(getActivity(), SecondaryActivity.class);
-                i.putExtra("fragment", SecondaryActivity.EQUALIZER);
-                startActivity(i);
-                dismiss();
+                showFragment(ID_EQUALIZER);
                 break;
             case ID_SAVE_PLAYLIST:
                 showFragment(ID_SAVE_PLAYLIST);
@@ -545,13 +537,14 @@ public class AdvOptionsDialog extends DialogFragment implements View.OnClickList
         mAdapter.addOption(new Option(ID_SLEEP, R.attr.ic_sleep_normal_style, getString(R.string.sleep_title)));
         mAdapter.addOption(new Option(ID_PLAYBACK_SPEED, R.attr.ic_speed_normal_style, getString(R.string.playback_speed)));
         mAdapter.addOption(new Option(ID_JUMP_TO, R.attr.ic_jumpto_normal_style, getString(R.string.jump_to_time)));
+        mAdapter.addOption(new Option(ID_EQUALIZER, R.attr.ic_equalizer_normal_style, getString(R.string.equalizer)));
 
         if (mMode == MODE_VIDEO) {
             if (!tvUi)
                 mAdapter.addOption(new Option(ID_PLAY_AS_AUDIO, R.attr.ic_playasaudio_on, getString(R.string.play_as_audio)));
             mAdapter.addOption(new Option(ID_SPU_DELAY, R.attr.ic_subtitledelay, getString(R.string.spu_delay)));
             mAdapter.addOption(new Option(ID_AUDIO_DELAY, R.attr.ic_audiodelay, getString(R.string.audio_delay)));
-            if (!tvUi || AndroidDevices.isAndroidTv() && AndroidUtil.isNougatOrLater)
+            if (!tvUi || AndroidDevices.hasPiP)
                 mAdapter.addOption(new Option(ID_POPUP_VIDEO, R.attr.ic_popup_dim, getString(R.string.popup_playback_title)));
             mAdapter.addOption(new Option(ID_REPEAT, R.attr.ic_repeat, getString(R.string.repeat_title)));
             if (mService.canShuffle())
@@ -564,7 +557,6 @@ public class AdvOptionsDialog extends DialogFragment implements View.OnClickList
                 large_items++;
             }
         } else {
-            mAdapter.addOption(new Option(ID_EQUALIZER, R.attr.ic_equalizer_normal_style, getString(R.string.equalizer)));
             mAdapter.addOption(new Option(ID_SAVE_PLAYLIST, R.attr.ic_save, getString(R.string.playlist_save)));
         }
         setDialogDimensions(large_items);
