@@ -1,7 +1,7 @@
 /*****************************************************************************
  * VerticalGridActivity.java
  *****************************************************************************
- * Copyright © 2014-2015 VLC authors, VideoLAN and VideoLabs
+ * Copyright © 2014-2016 VLC authors, VideoLAN and VideoLabs
  * Author: Geoffrey Métais
  *
  * This program is free software; you can redistribute it and/or modify
@@ -31,11 +31,11 @@ import android.widget.ProgressBar;
 import android.widget.TextView;
 
 import org.videolan.vlc.R;
+import org.videolan.vlc.VLCApplication;
 import org.videolan.vlc.gui.tv.MainTvActivity;
 import org.videolan.vlc.gui.tv.browser.interfaces.BrowserActivityInterface;
 import org.videolan.vlc.gui.tv.browser.interfaces.BrowserFragmentInterface;
 import org.videolan.vlc.gui.tv.browser.interfaces.DetailsFragment;
-import org.videolan.vlc.media.MediaLibrary;
 
 @TargetApi(Build.VERSION_CODES.JELLY_BEAN_MR1)
 public class VerticalGridActivity extends BaseTvActivity implements BrowserActivityInterface {
@@ -46,21 +46,24 @@ public class VerticalGridActivity extends BaseTvActivity implements BrowserActiv
     TextView mEmptyView;
 
     @Override
-    public void onCreate(Bundle savedInstanceState){
+    public void onCreate(Bundle savedInstanceState) {
         super.onCreate(savedInstanceState);
         setContentView(R.layout.tv_vertical_grid);
         mContentLoadingProgressBar = (ProgressBar) findViewById(R.id.tv_fragment_progress);
         mEmptyView = (TextView) findViewById(R.id.tv_fragment_empty);
-        getWindow().setBackgroundDrawableResource(R.drawable.background);
         long type = getIntent().getLongExtra(MainTvActivity.BROWSER_TYPE, -1);
         if (type == MainTvActivity.HEADER_VIDEO)
             mFragment = new VideoBrowserFragment();
         else if (type == MainTvActivity.HEADER_CATEGORIES)
             if (getIntent().getLongExtra(MusicFragment.AUDIO_CATEGORY, MusicFragment.CATEGORY_SONGS) == MusicFragment.CATEGORY_SONGS &&
-                    MediaLibrary.getInstance().getAudioItems().size() > GRID_LIMIT)
+                VLCApplication.getMLInstance().getAudioCount() > GRID_LIMIT) {
                 mFragment = new SongsBrowserFragment();
-            else
+            } else {
                 mFragment = new MusicFragment();
+                Bundle args = new Bundle();
+                args.putParcelable(MusicFragment.AUDIO_ITEM, getIntent().getParcelableExtra(MusicFragment.AUDIO_ITEM));
+                ((Fragment)mFragment).setArguments(args);
+            }
         else if (type == MainTvActivity.HEADER_NETWORK) {
             Uri uri = getIntent().getData();
             if (uri == null)
@@ -76,7 +79,7 @@ public class VerticalGridActivity extends BaseTvActivity implements BrowserActiv
             return;
         }
         getFragmentManager().beginTransaction()
-                .add(R.id.tv_fragment_placeholder, (Fragment) mFragment)
+                .add(R.id.tv_fragment_placeholder, ((Fragment)mFragment))
                 .commit();
     }
 
@@ -87,7 +90,8 @@ public class VerticalGridActivity extends BaseTvActivity implements BrowserActiv
 
     @Override
     protected void onNetworkUpdated() {
-        mFragment.updateList();
+        if (mFragment instanceof NetworkBrowserFragment)
+            mFragment.updateList();
     }
 
     public boolean onKeyDown(int keyCode, KeyEvent event)  {
